Struct block2::ConcreteBlock

source ·
#[repr(C)]
pub struct ConcreteBlock<A, R, F> { /* private fields */ }
An Objective-C block whose size is known at compile time and may be constructed on the stack.

Implementations

Constructs a ConcreteBlock with the given closure. When the block is called, it will return the value that results from calling the closure.

Copy self onto the heap as an RcBlock.

Methods from Deref<Target = Block<A, R>>

Call self with the given arguments.

Safety

This invokes foreign code that the caller must verify doesn’t violate any of Rust’s safety rules.

For example, if this block is shared with multiple references, the caller must ensure that calling it will not cause a data race.