Struct block2::ConcreteBlock
source · #[repr(C)]pub struct ConcreteBlock<A, R, F> { /* private fields */ }Expand description
An Objective-C block whose size is known at compile time and may be constructed on the stack.
Implementations
sourceimpl<A, R, F> ConcreteBlock<A, R, F>where
A: BlockArguments,
R: Encode,
F: IntoConcreteBlock<A, Output = R>,
impl<A, R, F> ConcreteBlock<A, R, F>where
A: BlockArguments,
R: Encode,
F: IntoConcreteBlock<A, Output = R>,
Methods from Deref<Target = Block<A, R>>
sourcepub unsafe fn call(&self, args: A) -> R
pub unsafe fn call(&self, args: A) -> R
Call self with the given arguments.
Safety
This invokes foreign code that the caller must verify doesn’t violate any of Rust’s safety rules.
For example, if this block is shared with multiple references, the caller must ensure that calling it will not cause a data race.